@@ -34,6 +34,12 @@ class User(TelegramObject):
         last_name (:obj:`str`): Optional. User's or bot's last name.
         username (:obj:`str`): Optional. User's or bot's username.
         language_code (:obj:`str`): Optional. IETF language tag of the user's language.
+        can_join_groups (:obj:`str`): Optional. True, if the bot can be invited to groups.
+            Returned only in :attr:`telegram.Bot.get_me` requests.
+        can_read_all_group_messages (:obj:`str`): Optional. True, if privacy mode is disabled
+            for the bot. Returned only in :attr:`telegram.Bot.get_me` requests.
+        supports_inline_queries (:obj:`str`): Optional. True, if the bot supports inline queries.
+            Returned only in :attr:`telegram.Bot.get_me` requests.
         bot (:class:`telegram.Bot`): Optional. The Bot to use for instance methods.
 
     Args:
@@ -43,6 +49,12 @@ class User(TelegramObject):
         last_name (:obj:`str`, optional): User's or bot's last name.
         username (:obj:`str`, optional): User's or bot's username.
         language_code (:obj:`str`, optional): IETF language tag of the user's language.
+        can_join_groups (:obj:`str`, optional): True, if the bot can be invited to groups.
+            Returned only in :attr:`telegram.Bot.get_me` requests.
+        can_read_all_group_messages (:obj:`str`, optional): True, if privacy mode is disabled
+            for the bot. Returned only in :attr:`telegram.Bot.get_me` requests.
+        supports_inline_queries (:obj:`str`, optional): True, if the bot supports inline queries.
+            Returned only in :attr:`telegram.Bot.get_me` requests.
         bot (:class:`telegram.Bot`, optional): The Bot to use for instance methods.
 
     """
@@ -54,6 +66,9 @@ class User(TelegramObject):
                  last_name=None,
                  username=None,
                  language_code=None,
+                 can_join_groups=None,
+                 can_read_all_group_messages=None,
+                 supports_inline_queries=None,
                  bot=None,
                  **kwargs):
         # Required
@@ -64,7 +79,9 @@ class User(TelegramObject):
         self.last_name = last_name
         self.username = username
         self.language_code = language_code
-
+        self.can_join_groups = can_join_groups
+        self.can_read_all_group_messages = can_read_all_group_messages
+        self.supports_inline_queries = supports_inline_queries
         self.bot = bot
 
         self._id_attrs = (self.id,)
@@ -99,7 +116,6 @@ class User(TelegramObject):
     def de_json(cls, data, bot):
         if not data:
             return None
-
         data = super(User, cls).de_json(data, bot)
 
         return cls(bot=bot, **data)
@@ -131,13 +147,26 @@ class User(TelegramObject):
             name (:obj:`str`): The name used as a link for the user. Defaults to :attr:`full_name`.
 
         Returns:
-            :obj:`str`: The inline mention for the user as markdown.
+            :obj:`str`: The inline mention for the user as markdown (version 1).
 
         """
         if name:
             return util_mention_markdown(self.id, name)
         return util_mention_markdown(self.id, self.full_name)
 
+    def mention_markdown_v2(self, name=None):
+        """
+        Args:
+            name (:obj:`str`): The name used as a link for the user. Defaults to :attr:`full_name`.
+
+        Returns:
+            :obj:`str`: The inline mention for the user as markdown (version 2).
+
+        """
+        if name:
+            return util_mention_markdown(self.id, name, version=2)
+        return util_mention_markdown(self.id, self.full_name, version=2)
+
     def mention_html(self, name=None):
         """
         Args:
